%{!?dotests:%define DO_TESTS 0}
%{?dotests:%define DO_TESTS 1}

%global __tar /opt/freeware/bin/tar

%global pkgname fribidi 

%define _libdir64 %{_prefix}/lib64

Name:           %{pkgname}
Version:        1.0.13
Release:        1
Summary:        The Free Implementation of the Unicode Bidirectional Algorithm. 
License:        LGPLv2.1
URL:            https://github.com/%{pkgname}/%{pkgname}
Source0:        https://github.com/fribidi/fribidi/releases/tag/v%{version}/%{pkgname}-%{version}.tar.xz
Patch1:		fribidi-shlib_version.patch

BuildRequires:  meson >= 1.2.0

%if %{toolchain} == "gcc"
Requires: libgcc >= 10.3.0
%endif

%description
Fribidi library implements the algorithm described in the "Unicode Standard Annex #9, The Bidirectional Algorithm", available at http://www.unicode.org/unicode/reports/tr9/.

The library uses Unicode (UTF-32) entirely. The character properties are automatically extracted from the Unicode data files, available from http://www.unicode.org/Public/UNIDATA/. This means that every Unicode character is treated in strict accordance with the Unicode specification.

%package devel
Summary:        The Free Implementation of the Unicode Bidirectional Algorithm.
Requires: pkg-config
Requires: %{name} = %{version}-%{release}

%description devel
The fribidi-devel package includes the header files for
the fribidi library.

%prep
%autosetup -n %{pkgname}-%{version}

# Duplicate source for 32 & 64 bits
rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -fr *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit

%build

cd 32bit/
export OBJECT_MODE=32
export CFLAGS="-D_ALL_SOURCE -maix32"
meson setup build --prefix=%{_prefix} --libdir=%{_libdir}
meson compile -C build -j8 --verbose

cd ../64bit
export OBJECT_MODE=64
export CFLAGS="-D_ALL_SOURCE -maix64"
meson setup build --prefix=%{_prefix} --libdir=%{_libdir64}
meson compile -C build -j8 --verbose

%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

install_fribidi()
{
set -x
export OBJECT_MODE=$1
LIBDIR=$2
export DESTDIR=${RPM_BUILD_ROOT}
meson install -C build --no-rebuild
(
    cd  ${RPM_BUILD_ROOT}/%{_prefix}/bin
    for fic in $(ls -1| grep -v -e _32 -e _64)
    do
        mv $fic "$fic"_${OBJECT_MODE}
        if [ ${OBJECT_MODE} -eq 64 ]
        then
             ln -sf "$fic"_${OBJECT_MODE} $fic
        fi
    done
)
}

cd 32bit/
install_fribidi 32 %{_libdir}
cd ../64bit/
install_fribidi 64 %{_libdir64}

# extract 64-bit shared object files from 64 bit libs
LISTLIB=`ls -1 ${RPM_BUILD_ROOT}%{_libdir64}/*.a | sed -e "s/.a\$//" | sed -e "s-.*/--g"`
cd ${RPM_BUILD_ROOT}%{_libdir64}
for lib in ${LISTLIB}
do
    /usr/bin/ar -X64 xv ${RPM_BUILD_ROOT}%{_libdir64}/${lib}.a  ${lib}.so.0
done

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
for lib in ${LISTLIB}
do
    /usr/bin/ar -q -X64 ${RPM_BUILD_ROOT}%{_libdir}/${lib}.a  ${lib}.so.0
done

%check
if [ "%{DO_TESTS}" == 1 ]
then

cd 32bit/build
(meson test || true)
cd ../../64bit/build
(meson test || true)
cd ../../

fi

# strip binaries
/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/*  || :

%files
%defattr(-,root,system,-)
%license 32bit/COPYING 
%doc 32bit/README.md
%{_bindir}/*
%{_libdir64}/*.a
%{_libdir}/*.a
%{_prefix}/share/man/man3/*

%files devel
%defattr(-,root,system,-)
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_libdir64}/pkgconfig/*

%changelog
* Thu Dec 07 2023 Aditya Kamath <Aditya.Kamath1@ibm.com> - 1.0.13
- Port fribidi to AIX.

